templates.problem_template.params

templates.problem_template.params

Functions

Name Description
parameters Template for generating training/testing parameter samples.

parameters

templates.problem_template.params.parameters(N_snap)

Template for generating training/testing parameter samples.

Uses generate_sobol from skrom.rom.rom_utils to sample uniformly over each interval in param_ranges.

Parameters

Name Type Description Default
N_snap int Number of samples per set. required

Returns

Name Type Description
params (ndarray, shape(2 * N_snap, D)) Stacked [training; testing] samples.
param_ranges list of tuple [(p1_min, p1_max), …, (pD_min, pD_max)] for each parameter.
train_mask ndarray of bool True for the first N_snap entries of params.
test_mask ndarray of bool True for the remaining entries.