templates.problem_template.domain
templates.problem_template.domain
Functions
| domain_ |
Template for setting up the computational domain and boundary conditions. |
domain_
templates.problem_template.domain.domain_(**kwargs)
Template for setting up the computational domain and boundary conditions.
Parameters
| kwargs |
dict |
Any problem-specific parameters needed for mesh generation, basis construction, and boundary identification. |
{} |
Returns
|
dict |
{ ‘mesh’: , ‘basis’: , ‘free_dofs’: , ‘dirichlet_dofs’: , ‘dirichlet_value’: , # add other entries as needed } |